const {
	generate_questions,
	inputQuestion,
	toggleQuestion,
	selectQuestion,
	dateQuestion
} = require('../utils/questions_generator');
const cli = require('../utils/cli');
const { generateReport } = require('../utils/report_generator');
const { debug } = cli.flags;
const { yellow: y, bold: b } = require('chalk');

const ElmBaseClass = require('./BaseClass');

class QuestionsGenerator extends ElmBaseClass {
	path_to_questions;

	constructor(title, key) {
		super();
		this.setServiceTitle(key, `🗒 ${b(title)}`);
	}

	setServiceTitle(key, title) {
		super.setServiceTitle(key, title);
	}

	setPath(path) {
		this.path_to_questions = path;
	}

	async initialize() {
		await super.initialize();
		let questions = await generate_questions(this.path_to_questions);
		let answers = await this.showQuestions(questions);
		return this.generateReport(answers);
	}

	async showQuestions(questions) {
		let answers = [];
		for (const question of questions) {
			switch (question.type) {
				case 'date':
					await dateQuestion(question, answers);
					console.log();
					break;
				case 'input':
					await inputQuestion(question, answers);
					console.log();
					break;
				case 'toggle':
					await toggleQuestion(question, answers);
					console.log();
					break;
				case 'select':
					await selectQuestion(question, answers);
					console.log();
					break;
			}
		}
		debug && console.log(answers);
		return answers;
	}

	async generateReport(answers) {
		return await generateReport(answers, this.path_to_questions);
	}
}

module.exports = QuestionsGenerator;
