const cheerio = require('cheerio');
const helper = require('../helpers');

const convertHtmlToObject = pageContent => {
	const content = cheerio.load(pageContent);

	let data = {};
	content('.wrapped')
		.map((i, element) => {
			let title = content(element)
				.find('h3')
				.text()
				.replace(/ /g, '_')
				.toLowerCase();
			const obj = {
				[title]: content(element)
					.find('tr')
					.map((i, element) => {
						if (i > 1) {
							let object = content(element)
								.find('td')
								.eq(1)
								.get();

							let isImage = false;
							let url = null;

							content(object)
								.find('img')
								.map((i, element) => {
									isImage = true;
									url = helper.removeQueryString(
										content(element).attr('src')
									);
								});

							return {
								date: content(element).find('td').eq(0).html(),
								URL:
									url ??
									content(element).find('td').eq(1).text(),
								isImage: isImage,
								note: content(element).find('td').eq(2).text()
							};
						}
					})
					.get()
			};
			data = { ...data, ...obj };
		})
		.get();
	return data;
};

const convertObjectToHtml = object => {
	let htmlContent = '';
	// set title
	htmlContent +=
		'<p><br/></p><h2><strong>Evidence:</strong></h2><p><br/></p>';

	Object.keys(object).forEach(key => {
		let title = key.replace(/_/g, ' ');
		htmlContent +=
			'<table class="wrapped"><colgroup><col/><col/><col/></colgroup><tbody>';

		htmlContent += `<tr> <th colspan="3"> <h3>${title}</h3> </th> </tr> <tr> <th>Date</th> <th>URL</th> <th>Note</th> </tr>`;

		if (object[key].length > 0) {
			object[key].forEach(item => {
				let finalContent = '';
				if (helper.isContainURL(item.URL) && item.isImage) {
					finalContent = `<a href="${item.URL}"> <img src="${item.URL}" alt="" width="100" /> </a>`;
				} else if (helper.isContainURL(item.URL) && !item.isImage) {
					finalContent = `<a href="${item.URL}">${item.URL}</a>`;
				} else {
					finalContent = item.URL;
				}
				if (item.date !== undefined) {
					htmlContent += `<tr> <td> ${item.date} </td> <td> ${finalContent} </td> <td>${item.note}</td> </tr>`;
				}
			});
		}

		htmlContent += '</tbody></table><br/><br/>';
	});

	return htmlContent;
};

module.exports = {
	convertHtmlToObject,
	convertObjectToHtml
};
